GCloud
=======

This workspace contains the basic tasks for provisioning and teardown of gcloud clusters

gce-new
=======
Provisions a new gce instance

gce
===
Provisions a new gce instance using the old topology format
